==> mabledsocli-1.0.74.dev2-py2.py3-none-any.whl: mabledsocli/provider/parameter/local/v1/main.py <==
import os
import re
from pathlib import Path
from mabledsocli.logger import Logger
from mabledsocli.config import Configs
from mabledsocli.providers import Providers
from mabledsocli.parameters import ParameterProvider
from mabledsocli.stages import Stages
from mabledsocli.constants import *
from mabledsocli.exceptions import DSOException
from mabledsocli.contexts import Contexts
from mabledsocli.local_utils import *
from mabledsocli.settings import *


_default_spec = {
    'path': os.path.join(Configs.config_dir, 'parameters'),
    'store': 'local.yaml',
    'format': 'yaml',
    'allowGroups': 'no',
    'prependGroups': 'yes',
    'groupDelimiter': '/',
    'nestedDelimiter': '.',
}


def get_default_spec():
    return _default_spec.copy()



config = {
    # 'parameters_dir' : '{0}/parameters'.format(Configs.dir_name),
    'file_extension' : {
        'yaml' : 'yml',
        'json' : 'json',
    }
}

class LocalParameterProvider(ParameterProvider):

    def __init__(self):
        super().__init__('parameter/local/v1')

    @property
    def root_dir(self):
        return Configs.parameter_spec('path')


    def get_path_prefix(self):
        return self.root_dir + os.sep

    @property
    def store_name(self):
        return Configs.parameter_spec('store')

 
    def add(self, project, application, stage, key, value):
        Logger.debug(f"Adding local parameter: stage={stage}, key={key}")
        response = add_local_parameter(stage, key, value, store_name=self.store_name, path_prefix=self.get_path_prefix())
        return response


    def list(self, project, application, stage, uninherited=False, filter=None):
        parameters = load_context_local_parameters(stage, store_name=self.store_name, path_prefix=self.get_path_prefix(), uninherited=uninherited, filter=filter)
        result = {'Parameters': []}
        for key, details in parameters.items():
            item = {
                'Key': key,
            }
            item.update(details)
            result['Parameters'].append(item)

        return result



    def get(self, project, application, stage, key, revision=None):
        if revision:
            raise DSOException(f"Parameter provider 'local/v1' does not support versioning.")
        Logger.debug(f"Getting parameter: stage={stage}, key={key}")
        found = locate_parameter_in_context_hierachy(stage=stage, key=key, store_name=self.store_name, path_prefix=self.get_path_prefix(), uninherited=False)
        if not found:
            raise DSOException(f"Parameter '{key}' not found nor inherited in the given context: stage={Stages.shorten(stage)}")
        result = {
                'Key': key, 
            }
        result.update(found[key])
        return result



    def delete(self, project, application, stage, key):
        Logger.debug(f"Locating parameter: stage={stage}, key={key}")
        ### only parameters owned by the context can be deleted, hence uninherited=True
        found = locate_parameter_in_context_hierachy(stage=stage, key=key, store_name=self.store_name, path_prefix=self.get_path_prefix(), uninherited=True)
        if not found:
            raise DSOException(f"Parameter '{key}' not found in the given context: stage={Stages.shorten(stage)}")
        Logger.info(f"Deleting parameter: path={found[key]['Path']}")
        delete_local_parameter(found[key]['Path'], key=key)
        result = {
                'Key': key,
                'Stage': Stages.shorten(stage),
                'Path': found[key]['Path'],
            }
        return result



def register():
    Providers.register(LocalParameterProvider())

==> mabledsocli-1.0.75.dev0-py2.py3-none-any.whl: mabledsocli/provider/parameter/local/v1/main.py <==
import os
from mabledsocli.logger import Logger
from mabledsocli.config import Configs
from mabledsocli.providers import Providers
from mabledsocli.parameters import ParameterProvider
from mabledsocli.stages import Stages
from mabledsocli.constants import *
from mabledsocli.exceptions import DSOException
from mabledsocli.contexts import Contexts
from mabledsocli.local_utils import *
from mabledsocli.settings import *


_default_spec = {
    'path': os.path.join(Configs.config_dir, 'parameters'),
    'store': 'local.yaml',
}


def get_default_spec():
    return _default_spec.copy()



class LocalParameterProvider(ParameterProvider):

    def __init__(self):
        super().__init__('parameter/local/v1')

    @property
    def root_dir(self):
        return self.config.parameter_spec('path')


    def get_path_prefix(self):
        return self.root_dir + os.sep


    @property
    def store_name(self):
        return self.config.parameter_spec('store')

 
    def add(self, config, key, value):
        self.config = config
        project = config.project
        application = config.application
        stage = Stages.normalize(config.stage)
        Logger.debug(f"Adding local parameter: stage={stage}, key={key}")
        response = add_local_parameter(stage, key, value, store_name=self.store_name, path_prefix=self.get_path_prefix())
        return response


    def list(self, config, uninherited=False, filter=None):
        self.config = config
        project = config.project
        application = config.application
        stage = Stages.normalize(config.stage)
        parameters = load_context_local_parameters(stage, store_name=self.store_name, path_prefix=self.get_path_prefix(), uninherited=uninherited, filter=filter)
        result = {'Parameters': []}
        for key, details in parameters.items():
            item = {
                'Key': key,
            }
            item.update(details)
            result['Parameters'].append(item)

        return result



    def get(self, config, key, revision=None):
        self.config = config
        project = config.project
        application = config.application
        stage = Stages.normalize(config.stage)
        if revision:
            raise DSOException(f"Parameter provider 'local/v1' does not support versioning.")
        Logger.debug(f"Getting parameter: stage={stage}, key={key}")
        found = locate_parameter_in_context_hierachy(stage=stage, key=key, store_name=self.store_name, path_prefix=self.get_path_prefix(), uninherited=False)
        if not found:
            raise DSOException(f"Parameter '{key}' not found nor inherited in the given context: stage={Stages.shorten(stage)}")
        result = {
                'Key': key, 
            }
        result.update(found[key])
        return result



    def delete(self, config, key):
        self.config = config
        project = config.project
        application = config.application
        stage = Stages.normalize(config.stage)
        Logger.debug(f"Locating parameter: stage={stage}, key={key}")
        ### only parameters owned by the context can be deleted, hence uninherited=True
        found = locate_parameter_in_context_hierachy(stage=stage, key=key, store_name=self.store_name, path_prefix=self.get_path_prefix(), uninherited=True)
        if not found:
            raise DSOException(f"Parameter '{key}' not found in the given context: stage={Stages.shorten(stage)}")
        Logger.info(f"Deleting parameter: path={found[key]['Path']}")
        delete_local_parameter(found[key]['Path'], key=key)
        result = {
                'Key': key,
                'Stage': Stages.shorten(stage),
                'Path': found[key]['Path'],
            }
        return result



def register():
    Providers.register(LocalParameterProvider())
